@@ -1150,10 +1150,53 @@ ACTUALIZE_RESULT_SCHEMA = '''{
         "tracedata": {
             "additionalProperties": false,
             "properties": {
+                "client": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "pattern": "\\w+",
+                    "type": "string"
+                },
                 "code": {
                     "maxLength": 256,
                     "minLength": 3,
                     "type": "string"
+                },
+                "method": {
+                    "enum": [
+                        "PLAN",
+                        "CONVERT",
+                        "ANALYTICS",
+                        "PREDICT",
+                        "ACTUALIZE",
+                        "VALIDATE",
+                        "ROUTE",
+                        "MATRIX",
+                        "CLUSTER"
+                    ],
+                    "type": "string"
+                },
+                "server": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "type": "string"
+                },
+                "service": {
+                    "enum": [
+                        "LASTMILE",
+                        "DELIVERY",
+                        "FIELDSERVICE",
+                        "MERCHANDISER",
+                        "ROUTING",
+                        "CLUSTERING",
+                        "ACCOUNT",
+                        "STOCK",
+                        "ADMIN"
+                    ],
+                    "type": "string"
+                },
+                "time": {
+                    "format": "date-time",
+                    "type": "string"
                 }
             },
             "required": [
