@@ -1028,6 +1028,13 @@ PLAN_TASK_SCHEMA = '''{
                         "minLength": 1,
                         "type": "string"
                     },
+                    "max_locations": {
+                        "default": 0,
+                        "format": "int32",
+                        "maximum": 1000,
+                        "minimum": 0,
+                        "type": "integer"
+                    },
                     "resource_key": {
                         "maxLength": 1024,
                         "minLength": 1,
@@ -1126,6 +1133,63 @@ PLAN_TASK_SCHEMA = '''{
             "minItems": 1,
             "type": "array"
         },
+        "tracedata": {
+            "additionalProperties": false,
+            "properties": {
+                "client": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "pattern": "\\w+",
+                    "type": "string"
+                },
+                "code": {
+                    "maxLength": 256,
+                    "minLength": 3,
+                    "type": "string"
+                },
+                "method": {
+                    "enum": [
+                        "PLAN",
+                        "CONVERT",
+                        "ANALYTICS",
+                        "PREDICT",
+                        "ACTUALIZE",
+                        "VALIDATE",
+                        "ROUTE",
+                        "MATRIX",
+                        "CLUSTER"
+                    ],
+                    "type": "string"
+                },
+                "server": {
+                    "maxLength": 256,
+                    "minLength": 2,
+                    "type": "string"
+                },
+                "service": {
+                    "enum": [
+                        "LASTMILE",
+                        "DELIVERY",
+                        "FIELDSERVICE",
+                        "MERCHANDISER",
+                        "ROUTING",
+                        "CLUSTERING",
+                        "ACCOUNT",
+                        "STOCK",
+                        "ADMIN"
+                    ],
+                    "type": "string"
+                },
+                "time": {
+                    "format": "date-time",
+                    "type": "string"
+                }
+            },
+            "required": [
+                "code"
+            ],
+            "type": "object"
+        },
         "transports": {
             "items": {
                 "additionalProperties": false,
